"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var util_1 = require("./../util");
var channel_1 = require("./channel");
var SocketIoChannel = (function (_super) {
    __extends(SocketIoChannel, _super);
    function SocketIoChannel(socket, name, options) {
        var _this = _super.call(this) || this;
        _this.events = {};
        _this.name = name;
        _this.socket = socket;
        _this.options = options;
        _this.eventFormatter = new util_1.EventFormatter(_this.options.namespace);
        _this.subscribe();
        _this.configureReconnector();
        return _this;
    }
    SocketIoChannel.prototype.subscribe = function () {
        this.socket.emit('subscribe', {
            channel: this.name,
            auth: this.options.auth || {}
        });
    };
    SocketIoChannel.prototype.unsubscribe = function () {
        this.unbind();
        this.socket.emit('unsubscribe', {
            channel: this.name,
            auth: this.options.auth || {}
        });
    };
    SocketIoChannel.prototype.listen = function (event, callback) {
        this.on(this.eventFormatter.format(event), callback);
        return this;
    };
    SocketIoChannel.prototype.on = function (event, callback) {
        var _this = this;
        var listener = function (channel, data) {
            if (_this.name == channel) {
                callback(data);
            }
        };
        this.socket.on(event, listener);
        this.bind(event, listener);
    };
    SocketIoChannel.prototype.configureReconnector = function () {
        var _this = this;
        var listener = function () {
            _this.subscribe();
        };
        this.socket.on('reconnect', listener);
        this.bind('reconnect', listener);
    };
    SocketIoChannel.prototype.bind = function (event, callback) {
        this.events[event] = this.events[event] || [];
        this.events[event].push(callback);
    };
    SocketIoChannel.prototype.unbind = function () {
        var _this = this;
        Object.keys(this.events).forEach(function (event) {
            _this.events[event].forEach(function (callback) {
                _this.socket.removeListener(event, callback);
            });
            delete _this.events[event];
        });
    };
    return SocketIoChannel;
}(channel_1.Channel));
exports.SocketIoChannel = SocketIoChannel;
//# sourceMappingURL=socketio-channel.js.map