"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var connector_1 = require("./connector");
var channel_1 = require("../channel");
var Pusher = require("pusher-nativescript");
var PusherConnector = (function (_super) {
    __extends(PusherConnector, _super);
    function PusherConnector() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.channels = {};
        return _this;
    }
    PusherConnector.prototype.connect = function () {
        if (typeof this.options.client !== 'undefined') {
            this.pusher = this.options.client;
        }
        else {
            this.pusher = new Pusher(this.options.key, this.options);
        }
    };
    PusherConnector.prototype.listen = function (name, event, callback) {
        return this.channel(name).listen(event, callback);
    };
    PusherConnector.prototype.channel = function (name) {
        if (!this.channels[name]) {
            this.channels[name] = new channel_1.PusherChannel(this.pusher, name, this.options);
        }
        return this.channels[name];
    };
    PusherConnector.prototype.privateChannel = function (name) {
        if (!this.channels['private-' + name]) {
            this.channels['private-' + name] = new channel_1.PusherPrivateChannel(this.pusher, 'private-' + name, this.options);
        }
        return this.channels['private-' + name];
    };
    PusherConnector.prototype.presenceChannel = function (name) {
        if (!this.channels['presence-' + name]) {
            this.channels['presence-' + name] = new channel_1.PusherPresenceChannel(this.pusher, 'presence-' + name, this.options);
        }
        return this.channels['presence-' + name];
    };
    PusherConnector.prototype.leave = function (name) {
        var _this = this;
        var channels = [name, 'private-' + name, 'presence-' + name];
        channels.forEach(function (name, index) {
            if (_this.channels[name]) {
                _this.channels[name].unsubscribe();
                delete _this.channels[name];
            }
        });
    };
    PusherConnector.prototype.leaveChannel = function (name) {
        if (this.channels[name]) {
            this.channels[name].unsubscribe();
            delete this.channels[name];
        }
    };
    PusherConnector.prototype.socketId = function () {
        return this.pusher.connection.socket_id;
    };
    PusherConnector.prototype.disconnect = function () {
        this.pusher.disconnect();
    };
    return PusherConnector;
}(connector_1.Connector));
exports.PusherConnector = PusherConnector;
//# sourceMappingURL=pusher-connector.js.map