"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var connector_1 = require("./connector");
var channel_1 = require("./../channel");
var SocketIO = require("nativescript-socket.io");
var application = require("tns-core-modules/application");
var SocketIoConnector = (function (_super) {
    __extends(SocketIoConnector, _super);
    function SocketIoConnector() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.channels = {};
        return _this;
    }
    SocketIoConnector.prototype.connect = function () {
        if (this.options.debug) {
            SocketIO.enableDebug();
        }
        this.socket = SocketIO.connect(this.options.host, this.options);
        return this.socket;
    };
    SocketIoConnector.prototype.listen = function (name, event, callback) {
        return this.channel(name).listen(event, callback);
    };
    SocketIoConnector.prototype.channel = function (name) {
        if (!this.channels[name]) {
            this.channels[name] = new channel_1.SocketIoChannel(this.socket, name, this.options);
        }
        return this.channels[name];
    };
    SocketIoConnector.prototype.privateChannel = function (name) {
        if (!this.channels['private-' + name]) {
            this.channels['private-' + name] = new channel_1.SocketIoPrivateChannel(this.socket, 'private-' + name, this.options);
        }
        return this.channels['private-' + name];
    };
    SocketIoConnector.prototype.presenceChannel = function (name) {
        if (!this.channels['presence-' + name]) {
            this.channels['presence-' + name] = new channel_1.SocketIoPresenceChannel(this.socket, 'presence-' + name, this.options);
        }
        return this.channels['presence-' + name];
    };
    SocketIoConnector.prototype.leave = function (name) {
        var _this = this;
        var channels = [name, 'private-' + name, 'presence-' + name];
        channels.forEach(function (name) {
            if (_this.channels[name]) {
                _this.channels[name].unsubscribe();
                delete _this.channels[name];
            }
        });
    };
    SocketIoConnector.prototype.leaveChannel = function (name) {
        if (this.channels[name]) {
            this.channels[name].unsubscribe();
            delete this.channels[name];
        }
    };
    SocketIoConnector.prototype.socketId = function () {
        var socketId;
        if (application.android)
            socketId = this.socket.android.id();
        else
            socketId = this.socket.ios.sid;
        return socketId;
    };
    SocketIoConnector.prototype.disconnect = function () {
        this.socket.disconnect();
    };
    return SocketIoConnector;
}(connector_1.Connector));
exports.SocketIoConnector = SocketIoConnector;
//# sourceMappingURL=socketio-connector.js.map